<!-- # **lynxy**
<b>Local <br>
(Yielding?) <br>
Network <br>
(eXchange?) <br>
(the extra y is cosmetic~)</b>
***
# **Introduction**
Lynxy , also known as lynx,  is a LAN server-client system coded in Python. It allows for easy setup of a server, as well as easy setup for clients on the same network as the server. 
Check out the github below to learn how to use Lynxy!
- [Github](https://github.com/SketchedDoughnut/lynxy) -->

# **What is Lynxy?**
<b>Lively <br>
(Yielding?) <br>
Network <br>
(eXchange?) <br>
(the extra y is cosmetic~)</b>

***

Lynxy is a client system coded in Python for ease of communication. It allows for easy set up for connecting
machines to each other, as well as providing a lot of extra features.

Check out the [Github](https://github.com/SketchedDoughnut/lynxy) to learn more!